@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Cookie Based Access Handler
 #
-# $Id: lonacc.pm,v 1.115 2008/05/14 18:27:30 raeburn Exp $
+# $Id: lonacc.pm,v 1.116 2008/09/15 19:08:44 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -187,6 +187,9 @@ sub sso_login {
 		      'server'    => $r->dir_config('lonHostID'),
 		      'sso.login' => 1
 		      );
+            if ($r->dir_config("ssodirecturl") == 1) {
+                $info{'origurl'} = $r->uri;
+            }
             if (defined($r->dir_config("lonSSOReloginServer"))) {
                 $info{'sso.reloginserver'} = 
                     $r->dir_config('lonSSOReloginServer'); 
@@ -239,7 +242,7 @@ sub handler {
 
     my $result = &sso_login($r,$handle);
     if (defined($result)) {
-	return $result
+	return $result;
     }
 
 
