@@ -17,6 +17,22 @@ if (!-x $dump_db || !-x $create_db) {
     exit(-1);
 }
 
+
+my $return_code = system("$create_db >& /dev/null");
+# create_db exits on 1 if no filename to create was specified and is thus
+# a successful start and stop of the program
+if ($return_code == -1
+    || (($return_code >> 8) != 1)) {
+    $create_db = '/home/httpd/perl/debug/create_db_dynamic_64_so.3';
+    printf("booM %d %d!\n",$return_code,($return_code >> 8 ));
+    $return_code = system("$create_db >& /dev/null");
+    if ($return_code == -1
+	|| (($return_code >> 8) != 1)) {
+	printf("booM2 %d %d!\n",$return_code,($return_code >> 8 ));
+	die("Unable to run need helper program create_db_dynamic_64");
+    }
+}
+
 my  %perlvar=%{&LONCAPA::Configuration::read_conf('loncapa.conf')};
 
 my $do_locks = 1;
