@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # chemical equation style response
 #
-# $Id: chemresponse.pm,v 1.78 2008/03/12 02:46:52 raeburn Exp $
+# $Id: chemresponse.pm,v 1.82 2008/09/21 20:28:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -163,6 +163,7 @@ CHEMPAGE
     my $docopen=&Apache::lonhtmlcommon::javascript_docopen();
     my $display=&mt('Draw Molecule');
     if (defined($shown_text)) { $display=&mt($shown_text); }
+    my $iconpath=$Apache::lonnet::perlvar{'lonIconsURL'};
     my $function = 
 	'LONCAPA_draw_molecule_'.&Apache::lonhtmlcommon::get_uniq_name();
     my $result=<<CHEMINPUT;
@@ -175,11 +176,10 @@ CHEMPAGE
 	editor.focus();
     }
 </script>
-<input type="button" value="$display" onclick="javascript:$function();void(0);" />
+<a href="javascript:$function();void(0);"><img class="stift" src='$iconpath/stift.gif' alt='$display' title='$display' /></a>
 CHEMINPUT
     return $result;
 }
-
 sub jme_img {
     my ($jme,$smile,$width,$options)=@_;
     my $id=&Apache::loncommon::get_cgi_id();
@@ -225,8 +225,8 @@ sub start_organicresponse {
 	    if (&Apache::response::show_answer()) {
 		$shown_text="Show Your Last Answer";
 	    }
-	    $result=&separate_jme_window("HWVAL_$id","MOLECULE_$id",$molecule,
-					 $options,$shown_text);
+	    #stift $result=&separate_jme_window("HWVAL_$id","MOLECULE_$id",$molecule,
+#					 $options,$shown_text);
 	    $result.= '<input type="hidden" name="MOLECULE_'.$id.'" value="" />';
 	}
     } elsif ($target eq 'edit') {
@@ -341,6 +341,23 @@ sub end_organicresponse {
 	    &Apache::lonhomework::set_bubble_lines();
 	}
     }
+    if (($target eq 'web' ) && ($Apache::lonhomework::type ne 'exam') && ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER')){
+            my $options=&Apache::lonxml::get_param('options',$parstack,
+                                                   $safeeval);
+            my $shown_text;
+            if (&Apache::response::show_answer()) {
+                $shown_text="Show Your Last Answer";
+            }
+	    my $molecule;
+	    if (defined($Apache::lonhomework::history{"resource.$partid.$id.molecule"})) {
+		$molecule=$Apache::lonhomework::history{"resource.$partid.$id.molecule"};
+	    } else {
+		$molecule=&Apache::lonxml::get_param('molecule',$parstack,
+						     $safeeval);
+	    }
+	$result.=&separate_jme_window("HWVAL_$id","MOLECULE_$id",$molecule,
+                             $options,$shown_text);
+    }
     &Apache::response::end_response();
     return $result;
 }
@@ -437,6 +454,8 @@ sub edit_reaction_button {
     my $field_es=&escape($field);
     my $reaction_es=&escape($reaction);
     my $docopen=&Apache::lonhtmlcommon::javascript_docopen();
+    my $iconpath=$Apache::lonnet::perlvar{'lonIconsURL'};
+    my $display=&mt('Edit Answer');
     my $start_page = 
 	&Apache::loncommon::start_page('LON-CAPA Reaction Editor',undef,
 				       {'frameset'    => 1,
@@ -458,7 +477,7 @@ sub edit_reaction_button {
     }
 // -->
 </script>
-<input type='button' value='Edit Answer' onclick="javascript:create_reaction_window_${id}_${field}();void(0);" />
+<a href="javascript:create_reaction_window_${id}_${field}();void(0);"><img class="stift" src='$iconpath/stift.gif' alt='$display' title='$display' /></a>
 EDITREACTION
     return $result;
 }
@@ -472,12 +491,6 @@ sub start_reactionresponse {
     } elsif ($target eq 'web') {
 	my $partid = $Apache::inputtags::part;
 	my $id = $Apache::inputtags::response['-1'];
-	my $reaction=$Apache::lonhomework::history{"resource.$partid.$id.submission"};
-	if ($reaction eq '') {  $reaction=&Apache::lonxml::get_param('initial',$parstack,$safeeval); }
-	my $status=$Apache::inputtags::status['-1'];
-	if ($status eq 'CAN_ANSWER') {
-	    $result.=&edit_reaction_button($id,"HWVAL_$id",$reaction);
-	}
 	if (  &Apache::response::show_answer() ) {
 	    my $ans=&Apache::lonxml::get_param('answer',$parstack,$safeeval);
 	    if (!$Apache::lonxml::default_homework_loaded) {
@@ -490,14 +503,13 @@ sub start_reactionresponse {
 	$result .=&Apache::edit::tag_start($target,$token);
 	my $answer=&Apache::lonxml::get_param('answer',$parstack,
 						$safeeval);
-	$result .='<nobr>'.
+	$result .='<span class="LC_nobreak">'.
 	    &Apache::edit::text_arg('Answer:','answer',$token,40);
-	$result .=&edit_reaction_button($id,&Apache::edit::html_element_name('answer'),$answer).'</nobr>';
+	$result .=&edit_reaction_button($id,&Apache::edit::html_element_name('answer'),$answer).'</span>';
 	my $initial=&Apache::lonxml::get_param('initial',$parstack,$safeeval);
-	$result.='<nobr>'.
+	$result.='<span class="LC_nobreak">'.
 	    &Apache::edit::text_arg('Initial Reaction:','initial',$token,40);
-	$result .=&edit_reaction_button($id,&Apache::edit::html_element_name('initial'),$initial).'</nobr>';
-	
+	$result .=&edit_reaction_button($id,&Apache::edit::html_element_name('initial'),$initial).'</span>';
 	$result .=&Apache::edit::end_row().&Apache::edit::start_spanning_row();
     }  elsif ($target eq 'modified') {
 	my $constructtag=&Apache::edit::get_new_args($token,$parstack,
@@ -571,6 +583,12 @@ sub end_reactionresponse {
             &Apache::lonhomework::set_bubble_lines();
         }
     }
+    my $status=$Apache::inputtags::status['-1'];
+    if  (($target eq 'web') && ($Apache::lonhomework::type ne 'exam') && ($status eq 'CAN_ANSWER')) {
+        my $reaction=$Apache::lonhomework::history{"resource.$partid.$id.submission"};
+        if ($reaction eq '') {  $reaction=&Apache::lonxml::get_param('initial',$parstack,$safeeval); }
+        $result.=&edit_reaction_button($id,"HWVAL_$id",$reaction);
+    }
     &Apache::response::end_response();
     return $result;
 }
