@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # essay (ungraded) style responses
 #
-# $Id: essayresponse.pm,v 1.87 2008/02/01 22:05:45 raeburn Exp $
+# $Id: essayresponse.pm,v 1.88 2008/08/28 00:14:42 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,7 +31,7 @@ use strict;
 use Apache::lonxml();
 use Apache::lonnet;
 use Apache::lonlocal;
-use LONCAPA;
+use LONCAPA qw(:DEFAULT :match);
  
 
 BEGIN {
@@ -70,10 +70,13 @@ sub start_essayresponse {
 
 	if ($ncol > 0) {
 	    $result .='<tr><td>'.'<label>'.
-		'Collaborators: <input type="text" size="70" max="80" name="HWCOL'.
-		$part.'_'.$id.'" value="'.$coll.'" /><br />'.
-		&mt('(Enter maximum [_1] collaborators using username or username@domain, e.g. smithje or smithje@[_2].)',$ncol,$env{'user.domain'}).
-                '</label><br />';
+		      &mt('Collaborators:').' <input type="text" size="70" max="80" name="HWCOL'.
+		      $part.'_'.$id.'" value="'.$coll.'" /><br />'.
+		      &mt('(Enter a maximum of [quant,_1,collaborator] using username or username:domain, e.g. smithje or smithje:[_2].)',$ncol,$env{'user.domain'});
+            if ($ncol > 1) {
+                $result .= '<br />'.&mt('If entering more than one, use spaces to separate the collaborators.');
+            }
+            $result .= '</label><br />';
 	    $result .= &check_collaborators($ncol,$coll) if ($coll =~ /\w+/);
 	    $result .='</td></tr>';
 	}
@@ -286,27 +289,43 @@ sub check_collaborators {
 					$env{'course.'.$env{'request.course.id'}.'.domain'},
 					$env{'course.'.$env{'request.course.id'}.'.num'});
     my (@badcollaborators,$result);
-    my (@collaborators) = split(/\,?\s+/,$coll);
-    foreach (@collaborators) {
-	my $collaborator = $_;
-	if (/@/) {
-	    $collaborator =~ s/@/:/;
+  
+    my (@collaborators) = split(/,?\s+/,$coll);
+    foreach my $entry (@collaborators) {
+        my $collaborator;
+	if ($entry =~ /:/) {
+	    $collaborator = $entry;
 	} else {
-	    $collaborator = $_.':'.$env{'user.domain'};
+	    $collaborator = $entry.':'.$env{'user.domain'};
 	}
-	push @badcollaborators, $_ if (!grep /^$collaborator/i,keys %classlist);
+        if ($collaborator !~ /^$match_username:$match_domain$/) {
+            if (!grep(/^\Q$entry\E$/,@badcollaborators)) {
+	        push(@badcollaborators,$entry);
+            }
+        } elsif (!grep(/^\Q$collaborator\E$/i,keys(%classlist))) {
+            if (!grep(/^\Q$entry\E$/,@badcollaborators)) {
+                push(@badcollaborators,$entry);
+            }
+        }
     }
     
-    if (scalar(@badcollaborators)) {
-	$result = '<table border="0"><tr bgcolor="#ffbbbb"><td> The following user'.
-	    (scalar(@badcollaborators) > 1 ? 's are' : ' is').' invalid: '.
-	    join(', ',@badcollaborators).'. Please correct.</td></tr></table>';
+    my $numbad = scalar(@badcollaborators);
+    if ($numbad) {
+	$result = '<table border="0"><tr bgcolor="#ffbbbb"><td>';
+        if ($numbad == 1) {
+            $result .= &mt('The following user is invalid:');
+        } else {
+            $result .= &mt('The following [_1] users are invalid:',$numbad);
+        }
+	$result .= ' '.join(', ',@badcollaborators).'. '.&mt('Please correct.').
+                   '</td></tr></table>';
     }
     my $toomany = scalar(@collaborators) - $ncol;
     if ($toomany > 0) {
 	$result .= '<table border="0"><tr bgcolor="#ffbbbb"><td>'.
-	    'You have too many collaborators. Please remove '.$toomany.' collaborator'.
-	    ($toomany > 1 ? 's' :'').'.</td></tr></table>';
+	           &mt('You have too many collaborators.').' '.
+                   &mt('Please remove [quant,_1,collaborator].',$toomany).
+	           '</td></tr></table>';
     }
     return $result;
 }
