@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # implements the tags that control the hints
 #
-# $Id: hint.pm,v 1.68 2007/05/23 22:36:21 albertel Exp $
+# $Id: hint.pm,v 1.71 2008/09/13 02:08:32 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -160,7 +160,7 @@ sub end_numericalhint {
 
 	my $partid=$Apache::inputtags::part;
 	my $id=$Apache::inputtags::hint[-1];
-	#id submissions occured under
+	#id submissions occurred under
 	my $submitid=$Apache::inputtags::response[-1];
 
 	my $response = $Apache::lonhomework::history{
@@ -395,7 +395,7 @@ sub end_stringhint {
 	&Apache::response::setup_params('stringhint',$safeeval);
 	my $partid=$Apache::inputtags::part;
 	my $id=$Apache::inputtags::hint[-1];
-	#id submissions occured under
+	#id submissions occurred under
 	my $submitid=$Apache::inputtags::response[-1];
 	my $response = $Apache::lonhomework::history{
 			    "resource.$partid.$submitid.submission"};
@@ -422,6 +422,9 @@ sub end_stringhint {
 	    my $args_ref = 
 		&Apache::caparesponse::setup_capa_args($safeeval,$parstack,
 						       \@args,$response);
+            if ($$args_ref{'type'} eq '') {
+                $$args_ref{'type'} = 'ci';
+            }
 	    &Apache::caparesponse::add_in_tag_answer($parstack,$safeeval);
 	    my (@final_awards,@final_msgs,@ans_names);
 	    my %answer = &Apache::caparesponse::get_answer();
@@ -530,7 +533,7 @@ sub end_optionhint {
 	my ($foilmatch,$conceptmatch)=(-1,-1);
 	my $name= &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	my $partid=$Apache::inputtags::part;
-	#id submissions occured under
+	#id submissions occurred under
 	my $submitid=$Apache::inputtags::response[-1];
 	my $part_id="$partid.$submitid";
 	my %answer;
@@ -610,7 +613,7 @@ sub end_radiobuttonhint {
 	my $answer=&Apache::lonxml::get_param('answer',$parstack,$safeeval);
 	eval('@answer ='.$answer);
 	my $partid=$Apache::inputtags::part;
-	#id submissions occured under
+	#id submissions occurred under
 	my $submitid=$Apache::inputtags::response[-1];
 	my $part_id="$partid.$submitid";
 	my $response = $Apache::lonhomework::history{
