@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.245 2008/09/01 10:01:57 bisitz Exp $
+# $Id: inputtags.pm,v 1.245.2.1 2008/09/19 22:31:54 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -736,7 +736,7 @@ sub decideoutput {
 	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'ERROR') {
-	$message = &mt('An error occured while grading your answer.');
+	$message = &mt('An error occurred while grading your answer.');
 	$css_class=$possible_class{'not_charged_try'};
 	$button = 1;
     } elsif ($award eq 'TOO_LONG') {
