@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # rank style response
 #
-# $Id: rankresponse.pm,v 1.56 2008/02/01 22:05:45 raeburn Exp $
+# $Id: rankresponse.pm,v 1.57 2008/08/08 16:37:13 bisitz Exp $
 # Copyright Michigan State University Board of Trustees
 #
 # This file is part of the LearningOnline Network with CAPA (LON-CAPA).
@@ -474,12 +474,12 @@ sub end_foil {
 	    my $name = &Apache::lonxml::get_param('name',$parstack,$safeeval);
 	    &Apache::lonxml::debug("Got a name of :$name:");
 	    if ($name eq "") {
-		&Apache::lonxml::warning("Foils without names exist. This can cause problems to malfunction.");
+		&Apache::lonxml::warning(&mt('Foils without names exist. This can cause problems to malfunction.'));
 		$name=$Apache::lonxml::curdepth;
 	    }
 	    &Apache::lonxml::debug("Using a name of :$name:");
 	    if (defined($Apache::response::foilnames{$name})) {
-		&Apache::lonxml::error(&mt("Foil name <b><tt>[_1]</tt></b> appears more than once. Foil names need to be unique.",$name));
+		&Apache::lonxml::error(&mt('Foil name [_1] appears more than once. Foil names need to be unique.','<b><tt>'.$name.'</tt></b>'));
 	    }
 	    $Apache::response::foilnames{$name}++;
 	    my $location =&Apache::lonxml::get_param('location',$parstack,
