@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # various response type definitons response definition
 #
-# $Id: response.pm,v 1.193 2008/06/14 20:16:57 www Exp $
+# $Id: response.pm,v 1.205 2008/09/23 19:15:57 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -486,9 +486,6 @@ sub start_mathresponse {
 						   $safeeval);
 	    $Apache::inputtags::answertxt{$id}=[$answer];
 	}
-        if ($Apache::inputtags::status['-1'] eq 'CAN_ANSWER') {
-            $result.=&edit_mathresponse_button($id,"HWVAL_$id");
-        }
 
     } elsif ($target eq 'edit') {
 	$result.=&Apache::edit::tag_start($target,$token);
@@ -523,6 +520,8 @@ sub start_mathresponse {
 sub edit_mathresponse_button {
     my ($id,$field)=@_;
     my $button=&mt('Edit Answer');
+#    my $helplink=&Apache::loncommon::help_open_topic('Formula_Editor');
+    my $iconpath=$Apache::lonnet::perlvar{'lonIconsURL'};
     return(<<ENDFORMULABUTTON);
 <script language="JavaScript">
 function edit_${id}_${field} (textarea) {
@@ -531,7 +530,7 @@ function edit_${id}_${field} (textarea) {
     newwin = window.open("/adm/dragmath/applet/MaximaPopup.html","","width=565,height=400,resizable");
 }
 </script>
-<input type='button' value='$button' onclick="javascript:edit_${id}_${field}('${field}');void(0);" />
+<a href="javascript:edit_${id}_${field}('${field}');void(0);"><img class="stift" src='$iconpath/stift.gif' alt='$button' title='$button'/></a>
 ENDFORMULABUTTON
 }
 
@@ -573,6 +572,12 @@ sub end_mathresponse {
     }
     if ($target eq 'web') {
 	&setup_prior_tries_hash(\&format_prior_response_math);
+        my $partid = $Apache::inputtags::part;
+        my $id = $Apache::inputtags::response[-1];
+        if (($Apache::inputtags::status['-1'] eq 'CAN_ANSWER')
+           && (&Apache::lonnet::EXT('resource.'.$partid.'_'.$id.'.turnoffeditor') ne 'yes')) {
+            $result.=&edit_mathresponse_button($id,"HWVAL_$id");
+        }
     }
 
     pop(@Apache::lonxml::namespace);
@@ -1187,7 +1192,7 @@ sub submitted {
     }
     # Submit All button on a .page was pressed
     if (defined($env{'form.all_submit'})) { return 1; }
-    # otherwise no submission occured
+    # otherwise no submission occurred
     return 0;
 }
 
