@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.429 2008/08/26 03:18:29 raeburn Exp $
+# $Id: structuretags.pm,v 1.431 2008/09/19 17:14:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1392,9 +1392,15 @@ sub end_languageblock {
 	    my $result = &Apache::lonxml::endredirection();
 	    my $which = &Apache::lonxml::get_param('which',$parstack,
 						   $safeeval);
-            foreach my $language (split(/\s*\,\s*/,$which)) {
-               unless ($language=~/\w/) { next; }
-               $available_texts{$language} = $result;
+            if ($which=~/\w/) {
+                $available_texts{$which} = $result;
+            }
+            my $otherlangs = &Apache::lonxml::get_param('other',$parstack,
+                                                        $safeeval);
+            foreach my $language (split(/\s*\,\s*/,$otherlangs)) {
+                if ($language=~/\w/) {
+                    $available_texts{$language} = $result;
+                }
             }
 
 	}
@@ -1493,7 +1499,7 @@ sub end_while {
 	    $return = &Apache::run::run($code,$safeeval);
 	}
 	if ($error) {
-	    &Apache::lonxml::error('<pre>'.&mt('Code ran too long. It ran for more than').' '.$Apache::lonnet::perlvar{'lonScriptTimeout'}.' '.&mt('seconds occured while running &lt;while&gt; on line').' '.$line.'</pre>');
+	    &Apache::lonxml::error('<pre>'.&mt('Code ran too long. It ran for more than').' '.$Apache::lonnet::perlvar{'lonScriptTimeout'}.' '.&mt('seconds occurred while running &lt;while&gt; on line').' '.$line.'</pre>');
 	}
     } elsif ($target eq "edit") {
 	$result.= &Apache::edit::tag_end($target,$token,'');
