@@ -3,7 +3,7 @@
 # institutional log-in ID (institutional authentication required - localauth
 #  or kerberos) or an e-mail address.
 #
-# $Id: createaccount.pm,v 1.23 2008/07/17 20:19:43 raeburn Exp $
+# $Id: createaccount.pm,v 1.25 2008/08/22 10:52:56 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -708,7 +708,7 @@ sub print_dataentry_form {
                     'lastname'       => "Last Name",
                     'generation'     => "Generation",
                     'permanentemail' => "Permanent e-mail address",
-                    'id'             => "ID/Student Number",
+                    'id'             => "Student/Employee ID",
                     'lg'             => "Login Data"
         );
         my %textboxsize = (
@@ -1084,7 +1084,7 @@ sub invalid_state {
     } elsif ($error eq 'existinguser') {
         $msg = &mt('The e-mail address you provided is already in use as a username in LON-CAPA at this institution.');
     } elsif ($error eq 'userrules') {
-        $msg = &mt('Username rules for this LON-CAPA at this institution do not allow the e-mail address you provided to be used as a username.');
+        $msg = &mt('Username rules at this institution do not allow the e-mail address you provided to be used as a username.');
     } elsif ($error eq 'userformat') {
         $msg = &mt('The e-mail address you provided may not be used as a username at this LON-CAPA institution.');
     } elsif ($error eq 'captcha') {
