@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # "About Me" Personal Information
 #
-# $Id: lonaboutme.pm,v 1.69 2008/01/20 22:25:05 raeburn Exp $
+# $Id: lonaboutme.pm,v 1.70 2008/09/11 02:07:27 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -620,9 +620,10 @@ sub parse_directory {
 
     my $portfolio_root = &Apache::portfolio::get_portfolio_root($cdom,$cnum,
                                                                 $group);
+    my $getpropath = 1;
     my %dirlist = map {
 	    ((split('&',$_,2))[0],1)
-	} &Apache::lonnet::dirlist($path,$cdom,$cnum,$portfolio_root);
+	} &Apache::lonnet::dirlist($portfolio_root.$path,$cdom,$cnum,$getpropath);
     foreach my $item (sort(keys(%{$currhash}))) {
         $output .= &portfolio_row_start();
         $output .= '<td style="padding-left: '.($depth*25).'px">';
