@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Announce
 #
-# $Id: lonannounce.pm,v 1.70 2008/05/18 19:45:46 www Exp $
+# $Id: lonannounce.pm,v 1.71.2.2 2008/09/25 01:53:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -38,6 +38,8 @@ use Apache::lonrss();
 use Apache::lonnet;
 use HTML::Entities();
 use LONCAPA qw(:match);
+use DateTime;
+use DateTime::TimeZone;
 
 my %todayhash;
 my %showedcheck;
@@ -292,11 +294,59 @@ sub order {
 }
 
 sub nextday {
-    my %th=@_;
-    $th{'day'}++;
+    my ($tk,%th)=@_;
+    my ($incmonth,$incyear);
+    if ($th{'day'} > 27) {
+        if ($th{'month'} == 2) {
+            if ($th{'day'} == 29) { 
+                $incmonth = 1;
+            } elsif ($th{'day'} == 28) {
+                if (!&is_leap_year($tk)) {
+                   $incmonth = 1;
+                }
+            }
+        } elsif (($th{'month'} == 4) || ($th{'month'} == 6) || 
+                 ($th{'month'} == 9) || ($th{'month'} == 11)) {
+            if ($th{'day'} == 30) {
+                $incmonth = 1;
+            }
+        } elsif ($th{'day'} == 31) {
+            if ($th{'month'} == 12) {
+                $incyear = 1;
+            } else {
+                $incmonth = 1;
+            }
+        }
+        if ($incyear) {
+            $th{'day'} = 1;
+            $th{'month'} = 1;
+            $th{'year'}++;
+        } elsif ($incmonth) {
+            $th{'day'} = 1;
+            $th{'month'}++;
+        } else {
+            $th{'day'}++;
+        }
+    } else {
+        $th{'day'}++;
+    }
     return (&Apache::loncommon::maketime(%th),$th{'month'});
 }
 
+sub is_leap_year {
+    my ($thistime) = @_;
+    my ($is_leap,$timezone,$dt);
+    $timezone = &Apache::lonlocal::gettimezone();
+    eval {
+        $dt = DateTime->from_epoch(epoch => $thistime)
+                      ->set_time_zone($timezone);
+    };
+    if (!$@) {
+        $is_leap = $dt->is_leap_year;
+    }
+    return $is_leap;
+}
+
 sub display_msg {
     my ($msg) = @_;
 
@@ -323,7 +373,7 @@ sub display_msg {
 sub showday {
     my ($tk,$mode,%allcal)=@_;
     my %th=&Apache::loncommon::timehash($tk);
-    my ($nextday,$nextmonth)=&nextday(%th);
+    my ($nextday,$nextmonth)=&nextday($tk,%th);
     my @outp;
     if ($mode) {
 	my $oneday=24*3600;
@@ -415,6 +465,13 @@ sub output_ics_file {
     $r->print("END:VCALENDAR$crlf");
 }
 
+sub show_timezone {
+    my $tzone = &Apache::lonlocal::gettimezone();
+    my $dt = DateTime->now();
+    my $tz = DateTime::TimeZone->new( name => $tzone );
+    return &mt('([_1] time zone)',$tz->short_name_for_datetime($dt));
+}
+
 sub handler {
     my $r = shift;
     if ($r->uri=~/\.(ics|ical)$/) {
@@ -446,12 +503,15 @@ sub handler {
 	'&element='.$env{'form.element'};
 # --------------------------------------------- Find out first day of the month
 
-    my %firstday=&Apache::loncommon::timehash(
-       &Apache::loncommon::maketime( 'day' => 1, 'month'=> $month,
-                                     'year' => $year, 'hours' => 0,
-				     'minutes' => 0, 'seconds' => 0,
-                                     'dlsav' => -1 ));
+    my $tk = &Apache::loncommon::maketime( 'day' => 1,
+                                           'month'=> $month,
+                                           'year' => $year, 
+                                           'hour' => 0,
+				           'minute' => 0, 
+                                           'second' => 0);
+    my %firstday = &Apache::loncommon::timehash($tk);
     my $weekday=$firstday{'weekday'};
+
 # ------------------------------------------------------------ Print the screen
     my $js = <<ENDDOCUMENT;
 <script type="text/javascript">
@@ -585,7 +645,7 @@ SERVERANNOUNCE
 		      &mt('June'),&mt('July'),&mt('August'),
                       &mt('September'),&mt('October'),
                       &mt('November'),&mt('December'))[$month].' '.
-	              $year.'</h1>');
+	              $year.' '.&show_timezone().'</h1>');
 # Reached the end of times, give up
     if (($year<1970) || ($year>2037)) {
 	$r->print('<h3>No calendar available for this date.</h3>'.
@@ -599,6 +659,36 @@ SERVERANNOUNCE
     if ($env{'form.pickdate'} eq 'yes') {
 	$class .= " LC_calendar_pickdate";
     }
+# ------------------------------------------------ Determine first day of a week
+#    my $datelocale =  &Apache::lonlocal::getdatelocale();
+    my $datelocale;
+    my $days_in_week = 7;
+    my $startweek = 0;
+    if (ref($datelocale)) {
+        $startweek = $datelocale->first_day_of_week();
+        if ($startweek == $days_in_week)  { $startweek = 0; }
+    }
+    my @days = ('Sun','Mon','Tue','Wed','Thu','Fri','Sat');
+    my @localdays;
+    if ($startweek == 0) {
+        @localdays = @days;
+    } else {
+        my $endday = $days_in_week - $startweek;
+        for (my $i=0; $i<$days_in_week; $i++) {
+            if ($i < $endday) {
+                $localdays[$i] = $days[$i+$startweek];
+            } else {
+                $localdays[$i] = $days[$i-$endday];
+            }
+        }
+    }
+
+# ----------------------------------------------------------- Weekday in locale
+    my $loc_weekday = $weekday - $startweek;
+    if ($loc_weekday < 0) {
+        $loc_weekday += $days_in_week; 
+    }
+
     $r->print(
  '<a href="/adm/announcements?month='.$pm.'&year='.$py.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Previous Month').'</a> '.
@@ -607,36 +697,44 @@ SERVERANNOUNCE
  '&nbsp;&nbsp;&nbsp;<a href="/adm/announcements?month='.$todayhash{'month'}.
  '&year='.$todayhash{'year'}.
  ($pickdatemode?$pickinfo:'').'">'.&mt('Current Month').'</a><p>'.
-        '<table class="'.$class.'" cols="7" rows="5"><tr>
-<th>'.&mt('Sun').'</th>
-<th>'.&mt('Mon').'</th>
-<th>'.&mt('Tue').'</th>
-<th>'.&mt('Wed').'</th>
-<th>'.&mt('Thu').'</th>
-<th>'.&mt('Fri').'</th>
-<th>'.&mt('Sat').'</th></tr>');
+        '<table class="'.$class.'" cols="7" rows="5"><tr>');
+    for (my $i=0; $i<@localdays; $i++) {
+        $r->print('<th>'.&mt($localdays[$i]).'</th>');
+    }
+    $r->print('</tr>');
 
-    my $tk=&Apache::loncommon::maketime(%firstday);
     my $outp;
     my $nm;
 
 # ---------------------------------------------------------------- Actual table
     $r->print('<tr>');
-    for (my $i=0;$i<$weekday;$i++) { $r->print(&emptycell); }
-    for (my $i=$weekday;$i<=6;$i++) { 
+    for (my $i=0;$i<$loc_weekday;$i++) { $r->print(&emptycell); }
+    for (my $i=$loc_weekday;$i<=6;$i++) {
         ($tk,$nm,$outp)=&showday($tk,0,%allcal);
         $r->print($outp);
     }
     $r->print('</tr>');
 
+    my $lastrow = 0;
+    my $lastday = 0;
     for (my $k=0;$k<=4;$k++) {
-        $r->print('<tr>');
-        for (my $i=0;$i<=6;$i++) {
-            ($tk,$nm,$outp)=&showday($tk,0,%allcal);
-            if ($month!=$nm) { $outp=&emptycell; }
-            $r->print($outp);
+        if (!$lastrow) {
+            $r->print('<tr>');
+            for (my $i=0;$i<=6;$i++) {
+                if ($lastday) {
+                    $outp = &emptycell();
+                } else {
+                    my $currtk = $tk;
+                    ($tk,$nm,$outp)=&showday($tk,0,%allcal);
+                    if ($month!=$nm) { $lastday = 1; }
+                }
+                $r->print($outp);
+            }
+            if ($lastday) {
+                $lastrow = 1;
+            }
+            $r->print('</tr>');
         }
-        $r->print('</tr>');
     }
 # ------------------------------------------------------------------- End table
     $r->print('</table>');
