@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Create a course
 #
-# $Id: loncreatecourse.pm,v 1.104.2.2 2007/12/23 17:36:56 raeburn Exp $
+# $Id: loncreatecourse.pm,v 1.108.2.1 2008/07/01 05:22:59 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -72,9 +72,9 @@ sub print_course_creation_page {
         my $starttime = time;
         my $endtime = time+(6*30*24*60*60); # 6 months from now, approx
         $enroll_table = &Apache::lonuserutils::date_setting_table($starttime,
-                                                $endtime,'create_enrolldates');
+                                              $endtime,'create_enrolldates');
         $access_table = &Apache::lonuserutils::date_setting_table($starttime,
-                                               $endtime,'create_defaultdates');
+                                             $endtime,'create_defaultdates');
         ($krbdef,$krbdefdom) =
         &Apache::loncommon::get_kerberos_defaults($defdom);
         $javascript_validations=&Apache::lonuserutils::javascript_validations(
@@ -129,6 +129,9 @@ function validate(formname) {
                     'cid'  => "Course ID",
                     'dmn'  => "Domain",
                     'asov' => "Additional settings, if specified below, will override cloned settings",
+                    'ncd'  => "Do not clone date parameters",
+                    'prd'  => 'Clone date parameters as-is',
+                    'shd'  => 'Shift date parameters by number of days',
                     'assp' => "Assessment Parameters",
                     'oaas' => "Open all assessments",
                     'mssg' => "Messaging",
@@ -301,6 +304,10 @@ $lt{'stat'}
     $lt{'dmn'}: $cloneform
 </label>
 <br />
+ <label><input type="radio" name="datemode" value="delete" /> $lt{'ncd'}</label><br />
+ <label><input type="radio" name="datemode" value="preserve" /> $lt{'prd'}</label><br />
+ <label><input type="radio" name="datemode" value="shift" checked="checked" /> $lt{'shd'}</label>
+ <input type="text" size="5" name="dateshift" value="365" /><br />
 &nbsp;<br />
 $lt{'asov'}.
 </td></tr>
@@ -487,7 +494,10 @@ ENDDOCUMENT
     $lt{'dmn'}: $cloneform
 </label>
 <br />
-&nbsp;<br />
+ <label><input type="radio" name="datemode" value="delete" /> $lt{'ncd'}</label><br />
+ <label><input type="radio" name="datemode" value="preserve" /> $lt{'prd'}</label><br />
+ <label><input type="radio" name="datemode" value="shift" checked="checked" /> $lt{'shd'}</label>
+ <input type="text" size="5" name="dateshift" value="365" /><br />&nbsp;<br />
 $lt{'asov'}.
 </td></tr>
 </table>
@@ -617,6 +627,8 @@ sub create_course {
                crsquota => $env{'form.crsquota'},
                clonecourse => $env{'form.clonecourse'},
                clonedomain => $env{'form.clonedomain'},
+               datemode => $env{'form.datemode'},
+               dateshift => $env{'form.dateshift'},
                crsid => $env{'form.crsid'},
                curruser => $env{'user.name'}.':'.$env{'user.domain'},
                crssections => $env{'form.crssections'},
@@ -650,23 +662,26 @@ sub create_course {
     # Check the veracity of the course coordinator
     if (&Apache::lonnet::homeserver($ccuname,$ccdomain) eq 'no_host') {
 	$r->print('<form action="/adm/createuser" method="post" name="crtuser">');
-        $r->print(&mt('No such user').' '.$ccuname.' '.&mt('at').' '.$ccdomain.'.<br />');
-	$r->print(&mt("Please click Back on your browser and select another user, or "));
-	$r->print('
-	    <input type="hidden" name="phase" value="get_user_info" />
-            <input type="hidden" name="ccuname" value="'.$ccuname.'" />
-            <input type="hidden" name="ccdomain" value="'.$ccdomain.'" />
-            <input name="userrole" type="submit" value="'.
-		  &mt('Create User').'" />
-	</form>'.&Apache::loncommon::end_page());
+        $r->print('<div class="LC_warning">'
+                  .&mt('No such user [_1] at domain [_2].','<tt>'.$ccuname.'</tt>','<tt>'.$ccdomain.'</tt>')
+                 .'</div>');
+	$r->print(&mt('Please click Back on your browser and select another user, or [_1]Create User[_2]'
+	             , '<input type="hidden" name="phase" value="get_user_info" />'
+                      .'<input type="hidden" name="ccuname" value="'.$ccuname.'" />'
+                      .'<input type="hidden" name="ccdomain" value="'.$ccdomain.'" />'
+                      .'<input name="userrole" type="submit" value="'
+                     , '" />'
+                     )
+                 .'</form>'.&Apache::loncommon::end_page()
+                 );
 	return;
     }
     # Check the proposed home server for the course
     my %host_servers = 
 	&Apache::lonnet::get_servers($env{'request.role.domain'},'library');
     if (! exists($host_servers{$env{'form.course_home'}})) {
-        $r->print(&mt('Invalid home server for course').': '.
-                  $env{'form.course_home'}.&Apache::loncommon::end_page());
+        $r->print(&mt('Invalid home server for course: [_1]'
+                     ,$env{'form.course_home'}.&Apache::loncommon::end_page()));
         return;
     }
     my ($courseid,$crsudom,$crsunum);
@@ -684,7 +699,7 @@ sub create_course {
 	    $r->print(&mt('Assigning role of [_1] Coordinator to [_2] at [_3]: ',
 			  $crstype,$ccuname,$ccdomain).
 		      &Apache::lonnet::assignrole($ccdomain,$ccuname,$courseid,
-						  'cc').'<p>');
+						  'cc','','','','','createcourse').'<p>');
 	}
 	if ($env{'form.setkeys'}) {
 	    $r->print(
@@ -702,11 +717,13 @@ sub create_course {
 sub print_intro_page {
     my $r = shift;
     my $start_page =
+#        &Apache::loncommon::start_page('Create a New Course or Group Space');
         &Apache::loncommon::start_page('Create a New Course');
     my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Creation Options','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
-    my $helplink=&Apache::loncommon::help_open_topic('Create_Course_GroupSpace',&mt('Help on Creating Courses and Groups'));
+#    my $helplink=&Apache::loncommon::help_open_topic('Create_Course_GroupSpace',&mt('Help on Creating Courses and Groups'));
+   my $helplink=&Apache::loncommon::help_open_topic('Create_Course_GroupSpace',&mt('Help on Creating Courses'));
 
     my @choices = ({ internal_name => 'courseone',
                      name => &mt('Create a single course'),
@@ -714,14 +731,15 @@ sub print_intro_page {
     &mt('Create a new course by completing an online form.'),
                  },
 #                   { internal_name => 'groupone',
-#                     name => &mt('Create a single collaborative group space '),
+#                     name => &mt('Create a single collaborative group space'),
 #                     short_description =>
-#    &mt('Create a new group space for non-course use by completing an online form .'),
+#    &mt('Create a new group space for non-course use by completing an online form.'),
 #                 },
                    { internal_name => 'batchone',
-                     name => &mt('Create courses/groups by uploading an attributes file'),
+#                     name => &mt('Create courses/groups by uploading an attributes file'),
+                     name => &mt('Create courses by uploading an attributes file'),
                      short_description =>
-    &mt('Upload an attributes file containing specifications for one or more courses or groups in XML format'),
+    &mt('Upload an attributes file containing specifications for one or more courses or groups in XML format.'),
                      help => 'Batch_Creation',
                  },
     );
@@ -748,18 +766,22 @@ ENDDOCUMENT
 sub upload_batchfile {
     my $r = shift;
     my $start_page =
-        &Apache::loncommon::start_page('Create a New Course or Group Space');
+#        &Apache::loncommon::start_page('Create a New Course or Group Space');
+        &Apache::loncommon::start_page('Create a New Course');
+#    my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course/Group Attributes File','Create_Course',undef,'Create_Courses');
     my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Upload Course Attributes File','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
     $r->print($start_page.$crumbs);
+#    $r->print('<h3>'.&mt('Upload a courses or groups attributes file').'</h3>');
     $r->print('<h3>'.&mt('Upload a courses attributes file').'</h3>');
     $r->print('<form name="batchcreate" method="post" '.
                 'enctype="multipart/form-data" action="/adm/createcourse">'.
               '<input type="file" name="coursecreatorxml" />'.
               '<input type="hidden" name="phase" value="batchtwo"><br /><br />'.
               '<input type="submit" name="batchsubmit" '.
-              'value="Create Courses/Groups" /></form>');
+#              'value="Create Courses/Groups" /></form>');
+              'value="'.&mt('Create Courses').'" /></form>');
     $r->print($end_page);
     return;
 }
@@ -767,7 +789,8 @@ sub upload_batchfile {
 sub process_batchfile {
     my $r = shift;
     my $start_page =
-        &Apache::loncommon::start_page('Create a New Course or Group Space');
+#        &Apache::loncommon::start_page('Create a New Course or Group Space');
+        &Apache::loncommon::start_page('Create a New Course');
     my $crumbs = &Apache::lonhtmlcommon::breadcrumbs('Creation Outcome','Create_Course',undef,'Create_Courses');
     my $end_page =
         &Apache::loncommon::end_page();
