@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # a pile of common html routines
 #
-# $Id: lonhtmlcommon.pm,v 1.179 2008/08/24 12:56:28 raeburn Exp $
+# $Id: lonhtmlcommon.pm,v 1.180 2008/09/05 22:12:47 riegler Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1310,6 +1310,8 @@ returns: nothing
         my $faq = '';
         my $bug = '';
 	my $help='';
+	# Crumb Symbol
+	my $crumbsymbol = ' &#x25b6; ';
         # The last breadcrumb does not have a link, so handle it separately.
         my $last = pop(@Crumbs);
         #
@@ -1333,7 +1335,7 @@ returns: nothing
                 });
         }
         my $links .= 
-            join('-&gt;',
+            join($crumbsymbol,
                  map {
                      $faq = $_->{'faq'} if (exists($_->{'faq'}));
                      $bug = $_->{'bug'} if (exists($_->{'bug'}));
@@ -1352,7 +1354,7 @@ returns: nothing
                      $result;
                      } @Crumbs
                  );
-        $links .= '-&gt;' if ($links ne '');
+        $links .= $crumbsymbol if ($links ne '');
 	if ($last->{'no_mt'}) {
 	    $links .= '<b>'.$last->{'text'}.'</b>';
 	} else {
