@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Routines to control the menu
 #
-# $Id: lonmenu.pm,v 1.239 2008/07/05 23:21:23 raeburn Exp $
+# $Id: lonmenu.pm,v 1.239.2.1 2008/09/20 17:01:48 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -251,10 +251,6 @@ ENDCRELOAD
         }
         my $form=&serverform();
 	my $utility=&utilityfunctions();
-	my $remote;
-	if ($env{'user.adv'}) {
-	    $remote = '<td><a href="/adm/remote?action=launch&amp;url='.$escurl.'" target="_top">'.$lt{'launch'}.'</a></td>'
-	}
 
         my $helplink=&Apache::loncommon::top_nav_help('Help');
 	return (<<ENDINLINEMENU);
@@ -272,7 +268,6 @@ $reloadlink
 $navmaps
 $docs
 $groups
-$remote
 $roles
 <td class="LC_top_nav_help">$helplink</td>
 <td class="LC_top_nav_exit"><a href="/adm/logout" target="_top">$lt{'exit'}</a></td>
