@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Sending messages
 #
-# $Id: lonnotify.pm,v 1.27 2007/11/13 03:53:30 raeburn Exp $
+# $Id: lonnotify.pm,v 1.28 2008/09/16 03:30:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -410,7 +410,7 @@ sub print_selection_form {
                      internal => 'text',
                      krb4 => 'text',
                      krb5 => 'text',
-                     local => 'text',
+                     localauth => 'text',
                      unix => 'text',
                    );
     $jscript .= &Apache::lonhtmlcommon::set_form_elements(\%elements);
@@ -778,7 +778,7 @@ sub form_elements {
                    krb5 => 'Kerberos 5',
                    internal => 'Internal (LON-CAPA)',
                    unix => 'Filesystem (UNIX)',
-                   local => 'Local/Customized',
+                   localauth => 'Local/Customized',
                    );
    return;
 }
