@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Pick a course
 #
-# $Id: lonpickcourse.pm,v 1.73.2.2 2008/07/01 05:26:04 raeburn Exp $
+# $Id: lonpickcourse.pm,v 1.73.2.4 2008/09/21 16:41:47 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -436,12 +436,12 @@ sub build_filters {
                       '15552000','31104000']));
 
     my %lt = (
-              'cac' => &mt('[_1] Activity',$type),
-              'cde' => &mt('[_1] Description',$type),
-              'cdo' => &mt('[_1] Domain',$type),
+              'cac' => &mt("$type Activity"),
+              'cde' => &mt("$type Description"),
+              'cdo' => &mt("$type Domain"),
               'cin' => &mt('Course Institutional Code'),
-              'cow' => &mt("[_1] Owner's Username",$type),
-              'cod' => &mt("[_1] Owner's Domain", $type),
+              'cow' => &mt("$type Owner's Username"),
+              'cod' => &mt("$type Owner's Domain"),
               'cog' => &mt('Course Type')
              );
 
