@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Quick Student Grades Display
 #
-# $Id: lonquickgrades.pm,v 1.41 2007/12/20 10:18:19 bisitz Exp $
+# $Id: lonquickgrades.pm,v 1.42 2008/08/17 23:25:40 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -145,7 +145,8 @@ HEADER
 		    my $score = 0;
 		    # If we're not telling status and the answer date isn't passed yet, 
 		    # it's an "attempted" point
-		    if ($curRes->problemstatus($part) eq 'no' &&
+		    if ((($curRes->problemstatus($part) eq 'no') ||
+                        ($curRes->problemstatus($part) eq 'no_feedback_ever')) &&
 			($dateStatus != $curRes->ANSWER_OPEN)) {
 			my $status = $curRes->simpleStatus($part);
 			if ($status == $curRes->ATTEMPTED) {
