@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstatistics.pm,v 1.139 2008/02/22 18:19:38 raeburn Exp $
+# $Id: lonstatistics.pm,v 1.141 2008/09/16 15:40:15 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -965,46 +965,55 @@ sub DisplayClasslist {
     my @selected_sections = &get_selected_sections();
     if (! @Students) {
         if ($selected_sections[0] eq 'all') { 
-            if (lc($env{'form.Status'}) eq 'any') {
-                $Str .= '<h2>'.
-                    &mt('There are no students in the course.').
-                    '</h2>';
-            } elsif (lc($env{'form.Status'}) eq 'active') {
-                $Str .= '<h2>'.
+            if (lc($env{'form.Status'}) eq 'active') {
+                $Str .= '<p class="LC_info">'.
                 &mt('There are no currently enrolled students in the course.').
-                    '</h2>';
+                    '</p>';
             } elsif (lc($env{'form.Status'}) eq 'expired') {
-                $Str .= '<h2>'.
+                $Str .= '<p class="LC_info">'.
                     &mt('There are no previously enrolled students in the course.').
-                        '</h2>';
+                        '</p>';
+            } elsif (lc($env{'form.Status'}) eq 'future') {
+                $Str .= '<p class="LC_info">'.
+                    &mt('There are no students with future access in the course.').
+                        '</p>';
+            } else { # 'any' and any others
+               $Str .= '<p class="LC_info">'.
+                    &mt('There are no students in the course.').
+                    '</p>';
             }
         } else { 
-            my $sections;
-            if (lc($env{'form.Status'}) eq 'any') {
-                $Str .= '<h2>'.
-                    &mt('There are no students in the selected sections.').
-                    '</h2>';
-            } elsif (lc($env{'form.Status'}) eq 'active') {
-                $Str .= '<h2>'.
+            if (lc($env{'form.Status'}) eq 'active') {
+                $Str .= '<p class="LC_info">'.
                     &mt('There are no currently enrolled students in the selected sections.').
-                    '</h2>';
+                    '</p>';
             } elsif (lc($env{'form.Status'}) eq 'expired') {
-                $Str .= '<h2>'.
+                $Str .= '<p class="LC_info">'.
                     &mt('There are no previously enrolled students in the selected sections.').
-                    '</h2>';
+                    '</p>';
+            } elsif (lc($env{'form.Status'}) eq 'future') {
+                $Str .= '<p class="LC_info">'.
+                    &mt('There are no students with future access in the selected sections.').
+                        '</p>';
+            } else { # 'any' and any others
+                $Str .= '<p class="LC_info">'.
+                    &mt('There are no students in the selected sections.').
+                    '</p>';
             }
         }
-        $Str.= '<a href="/adm/statistics?reportSelected=student_assessment">'.
-            &mt('Click here to return to the chart').'</a>';
+        $Str.= '<p>'
+              .'<a href="/adm/statistics?reportSelected=student_assessment">'
+              .&mt('Return to the chart').'</a>'
+              .'</p>';
         $r->print($Str);
         $r->rflush();
         return;
     }
 
-    # "Click" is asinine but it is probably not my place to change the world.
-    $Str .= '<h2>Click on a students name or username to view their chart</h2>';
-    $Str .= '<table border="0"><tr><td bgcolor="#777777">'."\n";
-    $Str .= '<table border="0" cellpadding="3"><tr bgcolor="#e6ffff">'."\n";
+    $Str .= '<h2>'.&mt('Select One Student').'</h2>'
+           .'<p>'.&mt("Click on a student's name or username to view their chart").'</p>'
+           .&Apache::loncommon::start_data_table()
+           .&Apache::loncommon::start_data_table_header_row();
     foreach my $field (@Fields) {
         $Str .= '<th><a href="/adm/statistics?'.
             'reportSelected=student_assessment&'.
@@ -1012,17 +1021,11 @@ sub DisplayClasslist {
             'sort='.$field.'">'.&mt($field).
             '</a></th>';
     }
-    $Str .= '</tr>'."\n";
+    $Str .= &Apache::loncommon::end_data_table_header_row();
     #
-    my $alternate = 0;
     foreach my $student (@Students) { # @Students is a package variable
         my $sname = $student->{'username'}.':'.$student->{'domain'};
-        if($alternate) {
-            $Str .= '<tr bgcolor="#ffffe6">';
-        } else {
-            $Str .= '<tr bgcolor="#ffffc6">';
-        }
-        $alternate = ($alternate + 1) % 2;
+        $Str .= &Apache::loncommon::start_data_table_row();
         #
         foreach my $field (@Fields) {
             $Str .= '<td>';
@@ -1041,9 +1044,9 @@ sub DisplayClasslist {
             }
             $Str .= '</td>';
         }
-        $Str .= "</tr>\n";
+        $Str .= &Apache::loncommon::end_data_table_row();
     }
-    $Str .= '</table></td></tr></table>'."\n";
+    $Str .= &Apache::loncommon::end_data_table();
     #
     $r->print($Str);
     $r->rflush();
@@ -1181,12 +1184,13 @@ ENDSTYLE
     #
         if (! &Apache::lonmysql::verify_sql_connection()) {
             my $serveradmin = $r->dir_config('lonAdmEMail');
-            $r->print('<h2><font color="Red">'.
+            $r->print('<h2 class="LC_error">'.
                       &mt('Unable to connect to database!').
-                      '</font></h2>');
-            $r->print('<p>'.
-                      &mt('Please notify the server administrator ').
-                      '<b>'.$serveradmin.'</b></p>');
+                      '</h2>');
+            $r->print('<p>'
+                     .&mt('Please notify the server administrator [_1]',
+                         ,'<b>'.$serveradmin.'</b>')
+                     .'</p>');
             $r->print('<p>'.
                       &mt('Course Statistics and Charts cannot be '.
                           'retrieved until the database is restarted.  '.
