@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler for requesting to have slots added to a students record
 #
-# $Id: slotrequest.pm,v 1.81 2008/01/14 14:32:30 raeburn Exp $
+# $Id: slotrequest.pm,v 1.83 2008/09/20 02:53:13 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -335,7 +335,7 @@ sub remove_registration {
     my %consumed=&Apache::lonnet::dump('slot_reservations',$cdom,$cnum,
 				       "^$slot_name\0");
     if (&Apache::lonnet::error(%consumed)) {
-	$r->print("<p><span class=\"LC_error\">".&mt('A network error has occured.').'</span></p>');
+	$r->print("<p><span class=\"LC_error\">".&mt('A network error has occurred.').'</span></p>');
 	return;
     }
     if (!%consumed) {
@@ -569,7 +569,9 @@ sub get_slot {
     my $slot_name=&check_for_conflict($symb,$env{'form.slotname'},\%slot);
 
     if ($slot_name =~ /^error: (.*)/) {
-	$r->print("<p><span class=\"LC_error\">An error occured while attempting to make a reservation. ($1)</span></p>");
+	$r->print('<p><span class="LC_error">'
+                 .&mt('An error occurred while attempting to make a reservation. ([_1])',$1)
+                 .'</span></p>');
 	&return_link($r);
 	return 0;
     }
@@ -610,7 +612,9 @@ STUFF
     if (defined($reserved)) {
 	my $retvalue = 0;
 	if ($slot_name =~ /^error: (.*)/) {
-	    $r->print("<p><span class=\"LC_error\">An error occured while attempting to make a reservation. ($1)</span></p>");
+	    $r->print('<p><span class="LC_error">'
+                     .&mt('An error occurred while attempting to make a reservation. ([_1])',$1)
+                     .'</span></p>');
 	} elsif ($reserved > -1) {
 	    $r->print("<p>Success: $description</p>");
 	    $retvalue = 1;
