@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonproblemstatistics.pm,v 1.112 2008/01/14 14:32:49 raeburn Exp $
+# $Id: lonproblemstatistics.pm,v 1.113 2008/09/11 14:47:22 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -714,7 +714,7 @@ sub BuildProblemStatisticsPage {
                   '</h3><p>'.
                   &mt('It may take some time to update the student data '.
                       'for the first analysis.  Future analysis this session '.
-                      ' will not have this delay.').
+                      'will not have this delay.').
                   '</p>');
 	&clean_up();
         return;
@@ -728,7 +728,7 @@ sub BuildProblemStatisticsPage {
     ($navmap,@sequences) = 
         &Apache::lonstatistics::selected_sequences_with_assessments();
     if (! ref($navmap)) {
-        $r->print('<h1>'.&mt('A course-wide error occured.').'</h1>'.
+        $r->print('<h1>'.&mt('A course-wide error occurred.').'</h1>'.
                   '<h3>'.$navmap.'</h3>');
 	&clean_up();
         return;
