@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstathelpers.pm,v 1.54 2006/12/29 21:47:11 albertel Exp $
+# $Id: lonstathelpers.pm,v 1.55 2008/09/14 15:16:29 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -86,7 +86,7 @@ sub render_resource {
     ## Render the problem
     my ($base) = ($resource->src =~ m|^(.*/)[^/]*$|);
     $base="http://".$ENV{'SERVER_NAME'}.$base;
-    my ($src,$symb)=($resource->src,&escape($resource->symb));
+    my ($src,$symb)=($resource->link,&escape($resource->shown_symb));
     my $rendered_problem = &Apache::lonnet::ssi_body($src.'?symb='.$symb);
     $rendered_problem =~ s/<\s*form\s*/<nop /g;
     $rendered_problem =~ s|(<\s*/form\s*>)|<\/nop>|g;
@@ -171,8 +171,7 @@ sub problem_selector {
                         if (scalar(@response_ids) > 1) {
                             $seq_str .= &mt('response').' '.$respid;
                         }
-                        my $link = $res->src.'?symb='.
-                            &escape($res->symb);
+                        my $link = $res->link.'?symb='.&escape($res->shown_symb);
                         $seq_str .= ('&nbsp;'x2).
                             qq{<a target="preview" href="$link">view</a>};
                         $seq_str .= "</td></tr>\n";
@@ -329,8 +328,8 @@ sub new_accumulator {
                     'value="'.&escape($res->symb).'" />'.
                     '&nbsp;'.$res->compTitle.'</label>'.
                     ('&nbsp;'x2).'<a target="preview" '.
-                    'href="'.$res->src.'?symb='.
-                         &escape($res->symb).'">view</a>'.
+                    'href="'.$res->link.'?symb='.
+                    &escape($res->shown_symb).'">view</a>'.
                     '</td></tr>'.$/;
             } else { 
                 if (defined($target)) {
