@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonstudentsubmissions.pm,v 1.46 2006/08/18 15:15:38 raeburn Exp $
+# $Id: lonstudentsubmissions.pm,v 1.48 2008/09/12 14:35:45 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -928,9 +928,9 @@ sub prepare_csv_output {
             time.'_'.rand(1000000000).'.csv';
     unless ($outputfile = Apache::File->new('>/home/httpd'.$filename)) {
         $r->log_error("Couldn't open $filename for output $!");
-        $r->print("Problems occured in writing the csv file.  ".
-                  "This error has been logged.  ".
-                  "Please alert your LON-CAPA administrator.");
+        $r->print(&mt('Problems occurred in writing the CSV file. '
+                     .'This error has been logged. '
+                     .'Please alert your LON-CAPA administrator.'));
         $outputfile = undef;
     }
     #
@@ -1046,9 +1046,9 @@ sub prepare_csv_output {
     # Close the progress window
     &Apache::lonhtmlcommon::Close_PrgWin($r,\%prog_state);
     #
-    # Tell the user where to get their csv file
+    # Tell the user where to get their CSV file
     $r->print('<br />'.
-              '<a href="'.$filename.'">'.&mt('Your csv file.').'</a>'."\n");
+              '<a href="'.$filename.'">'.&mt('Your CSV file.').'</a>'."\n");
     $r->rflush();
     return;
 }
