@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 #
-# $Id: lonsurveyreports.pm,v 1.15 2007/04/03 20:10:41 albertel Exp $
+# $Id: lonsurveyreports.pm,v 1.16 2008/09/14 15:16:30 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -203,8 +203,8 @@ sub SurveyProblemSelector {
         if ($env{'form.problemchoice'} eq $value) {
             $checked = 'checked ';
         }
-        my $link = $problem->{'res'}->src.
-            '?symb='.&escape($problem->{'res'}->symb);
+        my $link = $problem->{'res'}->link.
+            '?symb='.&escape($problem->{'res'}->shown_symb);
         $Str .= '<tr><td>'.
             '<input type="radio" name="problemchoice" id="'.$id.'" '.
                    'value="'.$value.'" '.$checked.'/>'.'</td>'.
