@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Localization routines
 #
-# $Id: lonlocal.pm,v 1.47 2008/07/02 21:31:32 raeburn Exp $
+# $Id: lonlocal.pm,v 1.48.2.1 2008/09/20 01:57:50 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -170,7 +170,7 @@ use DateTime::TimeZone;
 require Exporter;
 
 our @ISA = qw (Exporter);
-our @EXPORT = qw(mt mtn ns);
+our @EXPORT = qw(mt mtn ns mt_user);
 
 # ========================================================= The language handle
 
@@ -201,6 +201,27 @@ sub mt (@) {
     }
 }
 
+sub mt_user {
+    my ($user_lh,@what) = @_;
+    if ($user_lh) {
+        if ($what[0] eq '') {
+            if (wantarray) {
+                return @what;
+            } else {
+                return $what[0];
+            }
+        } else {
+            return $user_lh->maketext(@what);
+        }
+    } else {
+        if (wantarray) {
+            return @what;
+        } else {
+            return $what[0];
+        }
+    }
+}
+
 # ============================================================== What language?
 
 sub current_language {
@@ -279,6 +300,18 @@ sub gettimezone {
                 $timezone = $domdefaults{'timezone_def'};
             }
         }
+    } elsif ($Apache::lonnet::env{'request.role.domain'} ne '') {
+        my %uroledomdefs = 
+            &Apache::lonnet::get_domain_defaults($Apache::lonnet::env{'request.role.domain'});
+        if ($uroledomdefs{'timezone_def'} ne '') {
+            $timezone = $uroledomdefs{'timezone_def'};
+        }
+    } elsif ($Apache::lonnet::env{'user.domain'} ne '') {
+        my %udomdefaults = 
+            &Apache::lonnet::get_domain_defaults($Apache::lonnet::env{'user.domain'});
+        if ($udomdefaults{'timezone_def'} ne '') {
+            $timezone = $udomdefaults{'timezone_def'};
+        }
     }
     if ($timezone ne '') {
         if (DateTime::TimeZone->is_valid_name($timezone)) {
