@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.89 2008/05/27 17:33:28 www Exp $
+# $Id: loncfile.pm,v 1.90 2008/09/24 17:30:18 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1341,10 +1341,9 @@ sub handler {
 	$js = qq|
 <script type="text/javascript">
 function writeDone() {
-    var winName = window.opener
     window.focus();
-    winName.document.dataForm.newdir.value = "$newdirname"
-    setTimeout("self.close()",10000)
+    opener.document.info.newdir.value = "$newdirname";
+    setTimeout("self.close()",10000);
 }
   </script>
 |;
