@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.108 2008/01/17 04:50:57 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.110 2008/08/08 10:08:48 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -218,6 +218,7 @@ sub startpage {
 
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
     my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+    my $newname = &mt('New Name');
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
 top.document.title = '$esc_thisdisfn/ - $doctitle';
@@ -314,7 +315,7 @@ parent.lastknownpriv='/~$uname$esc_thisdisfn/';
     }
     function changename(theform,activity) {
         var oldname=theform.dispfilename.value;
-        var newname=prompt('New Name',oldname);
+        var newname=prompt('$newname',oldname);
         if (newname == "" || !newname || newname == oldname)  {
             return
         }
@@ -540,7 +541,7 @@ sub putdirectory {
 								 ));
         my $actionitem = '';
         if ($dirname eq '..') {
-            $actionitem = 'Go to ...';
+            $actionitem = &mt('Go to ...');
         } else {
             $actionitem = 
                     '<form name="dirselect_'.$$numdir.
@@ -655,7 +656,7 @@ sub putresource {
 	} 
 
 	$title.="\n".'<br /><a href="/~'.$uname.$thisdisfn.'/'.$filename.'.meta">'. 
-	    ($$bombs{$targetdir.'/'.$filename}?'<img src="/adm/lonMisc/bomb.gif" border="0" alt="bomb" />':'Edit Metadata').'</a>';
+	    ($$bombs{$targetdir.'/'.$filename}?'<img src="/adm/lonMisc/bomb.gif" border="0" alt="'.&mt('bomb').'" />':&mt('Edit Metadata')).'</a>';
 
 	if (!$meta_same) {
 	    $title = &mt('Metadata Modified').'<br />'.$title.
