@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.241 2008/07/26 19:05:27 raeburn Exp $
+# $Id: lonpublisher.pm,v 1.248 2008/08/27 13:08:36 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -118,6 +118,8 @@ use Apache::File;
 use File::Copy;
 use Apache::Constants qw(:common :http :methods);
 use HTML::LCParser;
+use HTML::Entities;
+use Encode::Encoder;
 use Apache::lonxml;
 use Apache::loncacc;
 use DBI;
@@ -264,8 +266,9 @@ sub metaread {
     my ($logfile,$fn,$prefix)=@_;
     unless (-e $fn) {
 	print($logfile 'No file '.$fn."\n");
-        return '<br /><b>'.&mt('No file').':</b> <tt>'.
-	    &Apache::loncfile::display($fn).'</tt>';
+        return '<div><b>'
+              .&mt('No file: [_1]'
+                  ,'</b> <tt>'.&Apache::loncfile::display($fn).'</tt></div>');
     }
     print($logfile 'Processing '.$fn."\n");
     my $metastring;
@@ -274,8 +277,9 @@ sub metaread {
 	$metastring=join('',<$metafh>);
     }
     &metaeval($metastring,$prefix);
-    return '<br /><b>'.&mt('Processed file').':</b> <tt>'.
-	&Apache::loncfile::display($fn).'</tt><br />';
+    return '<div><b>'
+          .&mt('Processed file: [_1]'
+              ,'</b> <tt>'.&Apache::loncfile::display($fn).'</tt></div>');
 }
 
 #########################################
@@ -843,15 +847,17 @@ sub store_metadata {
     # Determine if the table exists
     my $status = &Apache::lonmysql::check_table('metadata');
     if (! defined($status)) {
-        $error='<span class="LC_error">WARNING: Cannot connect to '.
-            'database!</span>';
+        $error='<span class="LC_error">'
+              .&mt('WARNING: Cannot connect to database!')
+              .'</span>';
         &Apache::lonnet::logthis($error);
         return ($error,undef);
     }
     if ($status == 0) {
         # It would be nice to actually create the table....
-        $error ='<span class="LC_error">WARNING: The metadata table does not '.
-            'exist in the LON-CAPA database.</span>';
+        $error ='<span class="LC_error">'
+               .&mt('WARNING: The metadata table does not exist in the LON-CAPA database!')
+               .'</span>';
         &Apache::lonnet::logthis($error);
         return ($error,undef);
     }
@@ -866,8 +872,9 @@ sub store_metadata {
                                                          \%metadata);
     }
     if (defined($status) && $status ne '') {
-        $error='<span class="LC_error">Error occured saving new values in '.
-            'metadata table in LON-CAPA database</span>';
+        $error='<span class="LC_error">'
+              .&mt('Error occurred saving new values in metadata table in LON-CAPA database!')
+              .'</span>';
         &Apache::lonnet::logthis($error);
         &Apache::lonnet::logthis($status);
         return ($error,undef);
@@ -887,17 +894,21 @@ sub checkonthis {
 					  'return_only_error_and_warning_counts' => 1));
     my ($errorcount,$warningcount)=split(':',$result);
     if (($errorcount) || ($warningcount)) {
-        $r->print('<br /><tt>'.$uri.'</tt>: ');
-	if ($errorcount) {
-	    $r->print('<img src="/adm/lonMisc/bomb.gif" /><span class="LC_error"><b>'.
-		      $errorcount.' '.
-		      &mt('error(s)').'</b></span> ');
-	}
-	if ($warningcount) {
-	    $r->print('<font color="blue">'.
-		      $warningcount.' '.
-		      &mt('warning(s)').'</font>');
-	}
+        $r->print('<h3>'.&mt('Warnings and Errors').'</h3>');
+        $r->print('<tt>'.$uri.'</tt>:');
+        $r->print('<ul>');
+        if ($warningcount) {
+            $r->print('<li><div class="LC_warning">'
+                     .&mt('[quant,_1,warning]',$warningcount)
+                     .'</div></li>');
+        }
+        if ($errorcount) {
+            $r->print('<li><div class="LC_error">'
+                     .&mt('[quant,_1,error]',$errorcount)
+                     .' <img src="/adm/lonMisc/bomb.gif" />'
+                     .'</div></li>');
+        }
+        $r->print('</ul>');
     } else {
 	#$r->print('<font color="green">'.&mt('ok').'</font>');
     }
@@ -936,7 +947,7 @@ backup copies, performs any automatic processing (prior to publication,
 especially for rat and ssi files),
 
 Returns a 2 element array, the first is the string to be shown to the
-user, the second is an error code, either 1 (an error occured) or 0
+user, the second is an error code, either 1 (an error occurred) or 0
 (no error occurred)
 
 I<Additional documentation needed.>
@@ -979,30 +990,30 @@ sub publish {
 	if ($error) { return ($outstring,$error); }
 # ------------------------------------------------------------ Construct Allows
     
-	$scrout.='<h3>'.&mt('Dependencies').'</h3>';
+        my $outdep=''; # Collect dependencies output data
         my $allowstr='';
         foreach my $thisdep (sort(keys(%allow))) {
 	   if ($thisdep !~ /[^\s]/) { next; }
            if ($thisdep =~/\$/) {
-              $scrout.='<br /><span class="LC_warning">'
+              $outdep.='<div class="LC_warning">'
                        .&mt('The resource depends on another resource with variable filename, i.e., [_1].','<tt>'.$thisdep.'</tt>').'<br />'
                        .&mt('You likely need to explicitly allow access to all possible dependencies using the [_1]-tag.','<tt>&lt;allow&gt;</tt>')
-                       .'</span><br />';
+                       ."</div>\n";
            }
            unless ($style eq 'rat') { 
               $allowstr.="\n".'<allow src="'.$thisdep.'" />';
 	   }
-           $scrout.='<br />';
+          $outdep.='<div>';
            if ($thisdep!~/[\*\$]/ && $thisdep!~m|^/adm/|) {
-	       $scrout.='<a href="'.$thisdep.'">';
+	       $outdep.='<a href="'.$thisdep.'">';
            }
-           $scrout.='<tt>'.$thisdep.'</tt>';
+           $outdep.='<tt>'.$thisdep.'</tt>';
            if ($thisdep!~/[\*\$]/ && $thisdep!~m|^/adm/|) {
-	       $scrout.='</a>';
+	       $outdep.='</a>';
                if (
        &Apache::lonnet::getfile($Apache::lonnet::perlvar{'lonDocRoot'}.'/'.
                                             $thisdep.'.meta') eq '-1') {
-		   $scrout.= ' - <span class="LC_error">'.&mt('Currently not available').
+		   $outdep.= ' - <span class="LC_error">'.&mt('Currently not available').
 		       '</span>';
                } else {
                    my %temphash=(&Apache::lonnet::declutter($target).'___'.
@@ -1015,6 +1026,12 @@ sub publish {
 		   }
 	       }
            }
+           $outdep.='</div><br />';
+        }
+
+        if ($outdep) {
+            $scrout.='<h3>'.&mt('Dependencies').'</h3>'
+                    .$outdep
         }
         $outstring=~s/\n*(\<\/[^\>]+\>[^<]*)$/$allowstr\n$1\n/s;
 
@@ -1168,17 +1185,22 @@ sub publish {
 	$textonly=~s/\<script[^\<]+\<\/script\>//g;
 	$textonly=~s/\<m\>[^\<]+\<\/m\>//g;
 	$textonly=~s/\<[^\>]*\>//g;
-	$textonly=~tr/A-Z/a-z/;
-	$textonly=~s/[\$\&][a-z]\w*//g;
-	$textonly=~s/[^a-z\s]//g;
-	
-	foreach ($textonly=~m/(\w+)/g) {
-	    unless ($nokey{$_}) {
-		$keywords{$_}=1;
-	    } 
-	}
-    }
 
+        #this is a work simplification for german authors for present
+        $textonly=HTML::Entities::decode($textonly);           #decode HTML-character
+        $textonly=Encode::Encoder::encode('utf8', $textonly);  #encode to perl internal unicode
+        $textonly=~tr/A-ZÜÄÖ/a-züäö/;      #add lowercase rule for german "Umlaute"
+        $textonly=~s/[\$\&][a-z]\w*//g;
+        $textonly=~s/[^a-z^ü^ä^ö^ß\s]//g;  #dont delete german "Umlaute"
+
+        foreach ($textonly=~m/[^\s]+/g) {  #match all but whitespaces
+            unless ($nokey{$_}) {
+                $keywords{$_}=1;
+            }
+        }
+
+
+    }
             
     foreach my $addkey (split(/[\"\'\,\;]/,$metadatafields{'keywords'})) {
 	$addkey=~s/\s+/ /g;
@@ -1199,7 +1221,7 @@ sub publish {
     my $intr_scrout.='<br />'
                     .'<form name="pubform" action="/adm/publish" method="post">';
     unless ($env{'form.makeobsolete'}) {
-       $intr_scrout.='<p>'
+       $intr_scrout.='<p class="LC_warning">'
                     .&mt('Searching for your resource will be based on the following metadata. Please provide as much data as possible.')
                     .'</p>'
                     .'<p><input type="submit" value="'
@@ -1238,29 +1260,44 @@ END
                 .'<input type="button" value="'.&mt('check all').'" onclick="javascript:checkAll(document.pubform.keywords)" />'
                 .'<input type="button" value="'.&mt('uncheck all').'" onclick="javascript:uncheckAll(document.pubform.keywords)" />'
                 .'</p><br />'
-                .&Apache::loncommon::start_data_table()
-                .&Apache::loncommon::start_data_table_row();
-
+                .&Apache::loncommon::start_data_table();
+    my $cols_per_row = 10;
     my $colcount=0;
+    my $wordcount=0;
+    my $numkeywords = scalar(keys(%keywords));
 
-    foreach (sort keys %keywords) {
-	$keywordout.='<td><label><input type="checkbox" name="keywords" value="'.$_.'"';
-	if ($metadatafields{'keywords'}) {
-	    if ($metadatafields{'keywords'}=~/\Q$_\E/) {
-		$keywordout.=' checked="on"';
-		$env{'form.keywords'}.=$_.',';
-	    }
-	} elsif (&Apache::loncommon::keyword($_)) {
-	    $keywordout.=' checked="on"';
-	    $env{'form.keywords'}.=$_.',';
-	}
-	$keywordout.=' />'.$_.'</label></td>';
-	if ($colcount>10) {
-	    $keywordout.="</tr><tr>\n";
-	    $colcount=0;
-	}
-	$colcount++;
+    foreach my $word (sort(keys(%keywords))) {
+        if ($colcount == 0) {
+            $keywordout .= &Apache::loncommon::start_data_table_row();
+        }
+        $colcount++;
+        $wordcount++;
+        if (($wordcount == $numkeywords) && ($colcount < $cols_per_row)) {
+            my $colspan = 1+$cols_per_row-$colcount;
+            $keywordout .= '<td colspan="'.$colspan.'">';
+        } else {
+            $keywordout .= '<td>';
+        }
+        $keywordout.='<label><input type="checkbox" name="keywords" value="'.$word.'"';
+        if ($metadatafields{'keywords'}) {
+            if ($metadatafields{'keywords'}=~/\Q$word\E/) {
+                $keywordout.=' checked="on"';
+                $env{'form.keywords'}.=$word.',';
+            }
+        } elsif (&Apache::loncommon::keyword($word)) {
+            $keywordout.=' checked="on"';
+            $env{'form.keywords'}.=$word.',';
+        }
+        $keywordout.=' />'.$word.'</label></td>';
+        if ($colcount == $cols_per_row) {
+            $keywordout.=&Apache::loncommon::end_data_table_row();
+            $colcount=0;
+        }
     }
+    if ($colcount > 0) {
+        $keywordout .= &Apache::loncommon::end_data_table_row();
+    }
+
     $env{'form.keywords'}=~s/\,$//;
 
     $keywordout.=&Apache::loncommon::end_data_table_row()
@@ -2156,9 +2193,7 @@ ENDCAPTION
         $r->print(&Apache::lonhtmlcommon::row_title(&mt('Target'))
                  .'<tt>'.$thisdistarget.'</tt>'
                  );
-# SB - ToDo:   
 	if (($cuname ne $env{'user.name'})||($cudom ne $env{'user.domain'})) {
-#           $r->print(&Apache::lonhtmlcommon::row_title('<span class="LC_warning">'.&mt('Co-Author').'</span>')
             $r->print(&Apache::lonhtmlcommon::row_closure()
                      .&Apache::lonhtmlcommon::row_title(&mt('Co-Author'))
                      .'<span class="LC_warning">'
@@ -2191,7 +2226,7 @@ ENDDIFF
 	    unless ($errorcount) {
 		my ($outstring,$error)=
 		    &publish($thisfn,$thistarget,$thisembstyle);
-		$r->print('<hr />'.$outstring);
+		$r->print($outstring);
 	    } else {
 		$r->print('<h3 class="LC_error">'.
 			  &mt('The document contains errors and cannot be published.').
