@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # TeX Conversion Module
 #
-# $Id: lontexconvert.pm,v 1.88 2008/07/18 13:09:33 raeburn Exp $
+# $Id: lontexconvert.pm,v 1.89 2008/09/10 19:45:23 droeschl Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -353,7 +353,7 @@ sub msgtexconverted {
 sub algebra {
     use AlgParser;
 
-    my ($string,$target,$style)=@_;
+    my ($string,$target,$style,$parstack,$safeeval)=@_;
     my $parser = new AlgParserWithImplicitExpand;
     $string=&prepare_algebra($string);
     my $ret = $parser->parse($string);
@@ -370,7 +370,9 @@ sub algebra {
 	    $latex='\\ensuremath{'.$latex.'}';
 	}
 	if ($target eq 'web' || $target eq 'analyze') {
-	    $result = &converted(\$latex);
+            my $display=&Apache::lonxml::get_param('display',$parstack,$safeeval);
+            $result = &converted(\$latex,$display);
+#	    $result = &converted(\$latex);
 	} else {
 	    $result = $latex;
 	}
