@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.484 2008/08/08 16:50:39 bisitz Exp $
+# $Id: lonxml.pm,v 1.484.2.1 2008/09/20 01:17:58 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1854,7 +1854,7 @@ sub error {
 	my ($symb)=&Apache::lonnet::symbread();
 	if ( !$symb ) {
 	    #public or browsers
-	    $errormsg=&mt("An error occured while processing this resource. The author has been notified.");
+	    $errormsg=&mt("An error occurred while processing this resource. The author has been notified.");
 	}
 	my $host=$Apache::lonnet::perlvar{'lonHostID'};
 	push(@errors,
@@ -1893,9 +1893,9 @@ sub error {
 		}
 	    }
 	    if ($env{'request.role.adv'}) {
-		$errormsg=&mt("An error occured while processing this resource. The course personnel ([_1]) and the author have been notified.",join(', ',@userlist));
+		$errormsg=&mt("An error occurred while processing this resource. The course personnel ([_1]) and the author have been notified.",join(', ',@userlist));
 	    } else {
-		$errormsg=&mt("An error occured while processing this resource. The instructor has been notified.");
+		$errormsg=&mt("An error occurred while processing this resource. The instructor has been notified.");
 	    }
 	}
 	push(@Apache::lonxml::error_messages,"<b>$errormsg</b> <br />");
