@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # <script> definiton
 #
-# $Id: scripttag.pm,v 1.147 2007/11/17 01:51:11 albertel Exp $
+# $Id: scripttag.pm,v 1.148 2008/09/10 19:45:23 droeschl Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -621,7 +621,7 @@ sub start_algebra {
 	$inside = &Apache::run::evaluate($inside,$safeeval,$$parstack[-1]);
 	if ($target eq 'web' || $target eq 'tex' || $target eq 'analyze') {
 	    my $style=&Apache::lonxml::get_param('style',$parstack,$safeeval);
-	    $result=&Apache::lontexconvert::algebra($inside,$target,$style);
+	    $result=&Apache::lontexconvert::algebra($inside,$target,$style,$parstack,$safeeval);
 	}
 	$Apache::lonxml::post_evaluate=0;
     }
