@@ -1,7 +1,7 @@
 <!--
 The LearningOnline Network
 Resource Assembly Tool
-// $Id: ratcode.js,v 1.6 2006/06/19 09:43:02 www Exp $
+// $Id: ratcode.js,v 1.7 2007/07/12 19:54:40 albertel Exp $
 //
 // Copyright Michigan State University Board of Trustees
 //
@@ -244,9 +244,10 @@ function newcondition(content,type) {
 }
 
 // ---------------------------------------------- Creates a new resource object
-function newresource(rid,cid,text,url,ext,type) {
+function newresource(rid,cid,text,url,ext,type,oldidx) {
    stored=0;
-   var newidx=addobj(rid,'b&'+rid+'&'+cid+':0:0:0',url);
+   var newidx=addobj(rid,'b&'+rid+'&'+cid+':0:0:0',url,oldidx);
+
    objcont[newidx]=
     text+':'+url+':'+ext+':'+type+':res';
    return newidx;
@@ -468,7 +469,7 @@ function insertport (obj1,d,inout,linkobj) {
 
 // ---------------------------- Make a new object and add it to the row content
 // returns object number of generated object
-function addobj(kjid,objs,url) {
+function addobj(kjid,objs,url,oldindex) {
    stored=0;
    expense++;
    if ((rowcont[kjid]!='') && (typeof(rowcont[kjid])!="undefined")) { 
@@ -476,13 +477,19 @@ function addobj(kjid,objs,url) {
    }
    var newindex=obj.length;
    if ((url!='') && (typeof(url)!="undefined")) {
-// see if we have a zombie with that url
+// see if we have a zombie with that url and possibly oldindex
       for (oidx=0;oidx<objcont.length;oidx++) {
           if (typeof(objcont[oidx])!="undefined") {
              data6=objcont[oidx].split(':');	
              if (data6[4]=='zombie') {
                 if (data6[1]==url) {
-                   newindex=oidx;
+		   if (typeof(oldindex) == "undefined") {
+                     newindex=oidx;
+                   } else {
+                     if (oidx == oldindex) {
+                       newindex=oidx;
+                     }
+                   }
                 }
              }
          }
