@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.88 2007/07/11 20:32:01 albertel Exp $
+# $Id: lonratedt.pm,v 1.89 2008/09/11 14:47:24 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -360,7 +360,7 @@ sub smpedt {
        unless ($fatal) {
 	   $targetmsg='<b>'.&mt('Saved.').'</b><br />';
        } else {
-	   $targetmsg='<b>'.&mt('An error occured while saving.').'</b><br />';
+	   $targetmsg='<b>'.&mt('An error occurred while saving.').'</b><br />';
        }
    }
    if ($env{'form.revert'}) {
