@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # routines for modyfing .sequence and .page files
 #
-# $Id: map.pm,v 1.10 2007/12/01 03:07:39 albertel Exp $
+# $Id: map.pm,v 1.11 2008/09/11 14:47:24 bisitz Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -456,7 +456,7 @@ sub loadmap {
         $instr=join('',@content);
     }
     if ($instr eq -2) {
-        $errtext.='Map not loaded: An error occured while trying to load the map.';
+        $errtext.='Map not loaded: An error occurred while trying to load the map.';
     } elsif ($instr eq '-1') {
 	# Map doesn't exist 
     } elsif ($instr) {
@@ -679,7 +679,7 @@ sub savemap {
             my $result=&Apache::lonnet::finishuserfileupload($2,$1,
 							     'output',$3);
 	    if ($result != m|^/uploaded/|) {
-		$errtext.='Map not saved: A network error occured when trying to save the map. ';
+		$errtext.='Map not saved: A network error occurred when trying to save the map. ';
 	    }
         } else {
 	    if (open(my $fh,">$fn")) {
